@@ -17,5 +17,5 @@ Including another URLconf
 from django.urls import path, include
 
 urlpatterns = [
-       path('', include('bi.urls')),
+       path('', include('apps.bi.urls')),
 ]
